@@ -21,6 +21,7 @@ from quickstats import semistaticmethod
 from quickstats.components import AbstractObject
 from quickstats.components.numerics import is_integer, pretty_value
 from quickstats.utils.root_utils import load_macro
+from quickstats.utils.common_utils import str_list_filter
 from quickstats.utils.roofit_utils import get_variable_attributes, variable_collection_to_dataframe
 
 class ExtendedModel(AbstractObject):
@@ -1396,11 +1397,14 @@ class ExtendedModel(AbstractObject):
             param_sets += [self.global_observables]
         for pstr, pset in zip(param_strs, param_sets):
             summary_str += f"{pstr} ({len(pset)}):\n"
+            param_names = [p.GetName() for p in pset]
+            param_names_to_include = param_names.copy()
             if include_patterns is not None:
-                pset = [p for pattern in include_patterns for p in pset if fnmatch.fnmatch(p.GetName(), pattern)]
+                param_names_to_include = str_list_filter(param_names_to_include, include_patterns, inclusive=True)
             if exclude_patterns is not None:
-                pset = [p for pattern in exclude_patterns for p in pset if not fnmatch.fnmatch(p.GetName(), pattern)]
-                
+                param_names_to_include = str_list_filter(param_names_to_include, exclude_patterns, inclusive=False)
+            param_index = np.in1d(param_names, param_names_to_include).nonzero()
+            pset = np.array(pset)[param_index]
             data = [get_variable_attributes(p) for p in pset]
             data = sorted(data, key=lambda d: d['name'])
             if detailed:
