@@ -7,6 +7,7 @@ import fnmatch
 import ROOT
 
 from quickstats.components import AbstractObject
+from quickstats.utils.common_utils import str_list_filter
 
 class RooInspector(AbstractObject):
     def __init__(self, tree_name:str, file_expr:Union[str, List[str]], 
@@ -39,7 +40,7 @@ class RooInspector(AbstractObject):
             self.rdf = self.rdf.Filter(filter_expr)
         
     def get_column_names(self)->List[str]:
-        column_names = [str(i) for i in self.rdf.GetColumnNames()]
+        column_names = sorted([str(i) for i in self.rdf.GetColumnNames()])
         return column_names
     
     def get_column_types(self, column_names:List[str])->Dict[str,str]:
@@ -60,9 +61,9 @@ class RooInspector(AbstractObject):
         summary_str += f"Number of Events: {nentries}\n"
         column_names = self.get_column_names()
         if include_patterns is not None:
-            column_names = [name for pattern in include_patterns for name in column_names if fnmatch.fnmatch(name, pattern)]
+            column_names = str_list_filter(column_names, include_patterns, inclusive=True)
         if exclude_patterns is not None:
-            column_names = [name for pattern in exclude_patterns for name in column_names if not fnmatch.fnmatch(name, pattern)]
+            column_names = str_list_filter(column_names, exclude_patterns, inclusive=False)
         column_types = self.get_column_types(column_names)
         n_columns = len(column_types)
         summary_str += f"Columns of Interest ({n_columns}):\n"
