@@ -40,7 +40,10 @@ class AbstractPlot:
             
         for key in handles:
             handle = handles[key]
-            label = handle.get_label()
+            if isinstance(handle, (tuple, list)):
+                label = handle[0].get_label()
+            else:
+                label = handle.get_label()
             if label and not label.startswith('_'):
                 legend_data[key] = {
                     'handle': handle,
