@@ -41,8 +41,8 @@ class UpperLimit1DPlot(AbstractPlot):
     
     def draw(self, logx:bool=False, xlabel:Optional[str]=None, markersize:float=50.,
              draw_observed:bool=True, draw_stat:bool=False, sig_fig:int=2):
-        if (draw_observed + draw_stat) != 1:
-            raise RuntimeError("either draw_observed or draw_stat should be set to True")
+        if (draw_observed + draw_stat) > 1:
+            raise RuntimeError("draw_observed and draw_stat can not be both True")
         n_category = len(self.category_df.columns)
         ax = self.draw_frame(logx=logx)
         transform = create_transform(transform_x='axis', transform_y='data')
@@ -51,6 +51,8 @@ class UpperLimit1DPlot(AbstractPlot):
             text_pos = {'observed': 0.775, 'expected': 0.925}
         if draw_stat:
             text_pos = {'expected': 0.775, 'stat': 0.925}
+        if (not draw_observed) and (not draw_stat):
+            text_pos = {'expected': 0.925}
         
         for i, category in enumerate(self.category_df):
             df = self.category_df[category]
